==> xml-psi-impl-231.8770.66-sources.jar: com/intellij/documentation/mdn/MdnDocumentedSymbol.kt <==
// Copyright 2000-2022 JetBrains s.r.o. and contributors. Use of this source code is governed by the Apache 2.0 license.
package com.intellij.documentation.mdn

import com.intellij.psi.PsiElement
import com.intellij.webSymbols.WebSymbol
import com.intellij.webSymbols.documentation.WebSymbolDocumentation

abstract class MdnDocumentedSymbol : WebSymbol {

  private val mdnDoc by lazy(LazyThreadSafetyMode.NONE) {
    getMdnDocumentation()
  }

  protected abstract fun getMdnDocumentation(): MdnSymbolDocumentation?

  override val deprecated: Boolean
    get() = mdnDoc?.isDeprecated ?: false

  override val experimental: Boolean
    get() = mdnDoc?.isExperimental ?: false

  override val description: String?
    get() = mdnDoc?.description

  override val docUrl: String?
    get() = mdnDoc?.url

  override val descriptionSections: Map<String, String>
    get() = mdnDoc?.sections ?: emptyMap()

  override fun createDocumentation(location: PsiElement?): WebSymbolDocumentation? =
    this.mdnDoc?.let { mdnDoc ->
      val documentation = super.createDocumentation(location)
      return documentation?.with(
        deprecated = false, // already contained in MDN documentation sections
        experimental = false, // already contained in MDN documentation sections
        footnote = mdnDoc.footnote
                     ?.let { it + (documentation.footnote?.let { prev -> "<br>$prev" } ?: "") }
                   ?: documentation.footnote,
      )
    } ?: super.createDocumentation(location)

}

==> xml-psi-impl-232.8660.197-sources.jar: com/intellij/documentation/mdn/MdnDocumentedSymbol.kt <==
// Copyright 2000-2022 JetBrains s.r.o. and contributors. Use of this source code is governed by the Apache 2.0 license.
package com.intellij.documentation.mdn

import com.intellij.psi.PsiElement
import com.intellij.webSymbols.WebSymbol
import com.intellij.webSymbols.WebSymbolApiStatus
import com.intellij.webSymbols.documentation.WebSymbolDocumentation

abstract class MdnDocumentedSymbol : WebSymbol {

  private val mdnDoc by lazy(LazyThreadSafetyMode.NONE) {
    getMdnDocumentation()
  }

  protected abstract fun getMdnDocumentation(): MdnSymbolDocumentation?

  override val apiStatus: WebSymbolApiStatus
    get() = when {
      mdnDoc?.isDeprecated == true -> WebSymbolApiStatus.Deprecated
      mdnDoc?.isExperimental == true -> WebSymbolApiStatus.Experimental
      else -> WebSymbolApiStatus.Stable
    }

  override val description: String?
    get() = mdnDoc?.description

  override val docUrl: String?
    get() = mdnDoc?.url

  override val descriptionSections: Map<String, String>
    get() = mdnDoc?.sections ?: emptyMap()

  override fun createDocumentation(location: PsiElement?): WebSymbolDocumentation? =
    this.mdnDoc?.let { mdnDoc ->
      val documentation = super.createDocumentation(location)
      return documentation?.with(
        apiStatus = null, // already contained in MDN documentation sections
        footnote = mdnDoc.footnote
                     ?.let { it + (documentation.footnote?.let { prev -> "<br>$prev" } ?: "") }
                   ?: documentation.footnote,
      )
    } ?: super.createDocumentation(location)

}
